package com.bonus.canteen.core.health.service;

import java.util.List;
import com.bonus.canteen.core.health.domain.HealthPersonInfoChronic;

/**
 * 人员健康慢性病关联Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface IHealthPersonInfoChronicService {
    /**
     * 查询人员健康慢性病关联
     * 
     * @param id 人员健康慢性病关联主键
     * @return 人员健康慢性病关联
     */
    public HealthPersonInfoChronic selectHealthPersonInfoChronicById(Long id);

    /**
     * 查询人员健康慢性病关联列表
     * 
     * @param healthPersonInfoChronic 人员健康慢性病关联
     * @return 人员健康慢性病关联集合
     */
    public List<HealthPersonInfoChronic> selectHealthPersonInfoChronicList(HealthPersonInfoChronic healthPersonInfoChronic);

    /**
     * 新增人员健康慢性病关联
     * 
     * @param healthPersonInfoChronic 人员健康慢性病关联
     * @return 结果
     */
    public int insertHealthPersonInfoChronic(HealthPersonInfoChronic healthPersonInfoChronic);

    /**
     * 修改人员健康慢性病关联
     * 
     * @param healthPersonInfoChronic 人员健康慢性病关联
     * @return 结果
     */
    public int updateHealthPersonInfoChronic(HealthPersonInfoChronic healthPersonInfoChronic);

    /**
     * 批量删除人员健康慢性病关联
     * 
     * @param ids 需要删除的人员健康慢性病关联主键集合
     * @return 结果
     */
    public int deleteHealthPersonInfoChronicByIds(Long[] ids);

    /**
     * 删除人员健康慢性病关联信息
     * 
     * @param id 人员健康慢性病关联主键
     * @return 结果
     */
    public int deleteHealthPersonInfoChronicById(Long id);
}
