package com.bonus.canteen.core.health.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.health.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.health.domain.HealthPersonInfoChronic;
import com.bonus.canteen.core.health.service.IHealthPersonInfoChronicService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 人员健康慢性病关联Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "人员健康慢性病关联接口")
@RestController
@RequestMapping("/health_person_info_chronic")
public class HealthPersonInfoChronicController extends BaseController {
    @Autowired
    private IHealthPersonInfoChronicService healthPersonInfoChronicService;

    /**
     * 查询人员健康慢性病关联列表
     */
    @ApiOperation(value = "查询人员健康慢性病关联列表")
    //@RequiresPermissions("health:chronic:list")
    @GetMapping("/list")
    public TableDataInfo list(HealthPersonInfoChronic healthPersonInfoChronic) {
        startPage();
        List<HealthPersonInfoChronic> list = healthPersonInfoChronicService.selectHealthPersonInfoChronicList(healthPersonInfoChronic);
        return getDataTable(list);
    }

    /**
     * 导出人员健康慢性病关联列表
     */
    @ApiOperation(value = "导出人员健康慢性病关联列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:export")
    @SysLog(title = "人员健康慢性病关联", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出人员健康慢性病关联")
    @PostMapping("/export")
    public void export(HttpServletResponse response, HealthPersonInfoChronic healthPersonInfoChronic) {
        List<HealthPersonInfoChronic> list = healthPersonInfoChronicService.selectHealthPersonInfoChronicList(healthPersonInfoChronic);
        ExcelUtil<HealthPersonInfoChronic> util = new ExcelUtil<HealthPersonInfoChronic>(HealthPersonInfoChronic.class);
        util.exportExcel(response, list, "人员健康慢性病关联数据");
    }

    /**
     * 获取人员健康慢性病关联详细信息
     */
    @ApiOperation(value = "获取人员健康慢性病关联详细信息")
    //@RequiresPermissions("health:chronic:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(healthPersonInfoChronicService.selectHealthPersonInfoChronicById(id));
    }

    /**
     * 新增人员健康慢性病关联
     */
    @ApiOperation(value = "新增人员健康慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:add")
    @SysLog(title = "人员健康慢性病关联", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增人员健康慢性病关联")
    @PostMapping
    public AjaxResult add(@RequestBody HealthPersonInfoChronic healthPersonInfoChronic) {
        try {
            return toAjax(healthPersonInfoChronicService.insertHealthPersonInfoChronic(healthPersonInfoChronic));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改人员健康慢性病关联
     */
    @ApiOperation(value = "修改人员健康慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:edit")
    @SysLog(title = "人员健康慢性病关联", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改人员健康慢性病关联")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody HealthPersonInfoChronic healthPersonInfoChronic) {
        try {
            return toAjax(healthPersonInfoChronicService.updateHealthPersonInfoChronic(healthPersonInfoChronic));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除人员健康慢性病关联
     */
    @ApiOperation(value = "删除人员健康慢性病关联")
    //@PreventRepeatSubmit
    //@RequiresPermissions("health:chronic:remove")
    @SysLog(title = "人员健康慢性病关联", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除人员健康慢性病关联")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(healthPersonInfoChronicService.deleteHealthPersonInfoChronicByIds(ids));
    }
}
